// use twelite mwx c++ template library
#include <TWELITE>
#include <NWK_SIMPLE>
#include <MONOSTICK>

/*** Config part */
// application ID
const uint32_t APP_ID = 0x1234abcd;

// channel
const uint8_t CHANNEL = 13;

const char APP_FOURCHAR[] = "BAT1";

/*** function prototype */

/*** application defs */

/*** setup procedure (run once at cold boot) */
void setup() {
	/*** SETUP section */
	auto&& brd = the_twelite.board.use<MONOSTICK>();
	brd.set_led_red(LED_TIMER::ON_RX, 200); // RED (on receiving)
	brd.set_led_yellow(LED_TIMER::BLINK, 500); // YELLOW (blinking)

	// the twelite main class
	the_twelite
		<< TWENET::appid(APP_ID)    // set application ID (identify network group)
		<< TWENET::channel(CHANNEL) // set channel (pysical channel)
		<< TWENET::rx_when_idle();  // open receive circuit (if not set, it can't listen packts from others)

	// Register Network
	auto&& nwksmpl = the_twelite.network.use<NWK_SIMPLE>();
	nwksmpl << NWK_SIMPLE::logical_id(0x00); // set Logical ID. (0x00 means parent device)

	/*** BEGIN section */
	the_twelite.begin(); // start twelite!

	/*** INIT message */
	Serial << "--- MONOSTICK_Parent act ---" << '\n';
}

/*** loop procedure (called every event) */
void loop() {
	// receive RF packet.
    if (the_twelite.receiver.available()) 
	{
		auto&& rx = the_twelite.receiver.read();
		// expand packet payload (shall match with sent packet data structure, see pack_bytes())
		char fourchars[5]{}; // init all elements as default (0).
		auto&& np = expand_bytes(rx.get_payload().begin(), rx.get_payload().end()
			, make_pair((uint8_t*)fourchars, 4)  // 4bytes of msg
		);

		// check header
		if (strncmp(APP_FOURCHAR, fourchars, 4)) { return; }

		// read rest of payload
		uint8_t u8DI_BM_remote = 0xff;
		uint16_t au16AI_remote[3];
		expand_bytes(np, rx.get_payload().end()
			, u8DI_BM_remote
			, au16AI_remote[0]//temp
			, au16AI_remote[1]//humidity
			, au16AI_remote[2]//pressure
		);

		int16 temp =  int16(au16AI_remote[0]);
		Serial << "T=" << format("%d  ", temp);
		Serial << "H=" << format("%d  ", au16AI_remote[1]);
		Serial << "P=" << format("%d  ", au16AI_remote[2]);
		Serial << '\n';
	}
}

/* Copyright (C) 2019 Mono Wireless Inc. All Rights Reserved.    *
 * Released under MW-SLA-*J,*E (MONO WIRELESS SOFTWARE LICENSE   *
 * AGREEMENT).                                                   */